powered by
Executes a list of job specifications in parallel, applies the given function with error handling, and collects the results or error messages.
bg_func(jobs, n_daemons)
A list of results, with error messages in case of failure.
A list of job specifications, each containing a function (fun) and arguments (args).
fun
args
Number of parallel workers