Learn R Programming

bakerrr (version 0.2.0)

summary: Summary method for bakerrr S7 job objects

Description

Provides a one-line summary of a bakerrr job object, indicating the status, function name, number of worker daemons, and total jobs. Prints a status icon and brief job info.

Usage

summary(x, ...)

Value

The input x, invisibly, after printing the summary.

Arguments

x

A bakerrr S7 job object.

...

Additional arguments (currently ignored).